<?php

  namespace Drupal\node_action_log\Form;

  use Drupal\Core\Form\FormBase;
  use Drupal\Core\Form\FormStateInterface;

  /**
   * Provides the database logging filter form.
   *
   * @internal
   */
  class FilterForm extends FormBase {

    /**
     * {@inheritdoc}
     */
    public function getFormId() {
      return 'nal_filter_form';
    }

    /**
     * {@inheritdoc}
     */
    public function buildForm(array $form, FormStateInterface $form_state) {
      $filters = [
        'created' => $this->t('Created'),
        'updated' => $this->t('Updated'),
        'deleted' => $this->t('Deleted'),
      ];

      $form['filters'] = [
        '#type' => 'details',
        '#title' => $this->t('Filter log messages'),
        '#open' => TRUE,
      ];
      $form['filters']['key'] = [
        '#title' => $this->t('Type'),
        '#type' => 'select',
        '#multiple' => TRUE,
        '#size' => 8,
        '#options' => $filters,
      ];
      if (!empty($_SESSION['nal_filter_key'])) {
        $form['filters']['key']['#default_value'] = $_SESSION['nal_filter_key'];
      }

      $form['filters']['actions'] = [
        '#type' => 'actions',
        '#attributes' => ['class' => ['container-inline']],
      ];
      $form['filters']['actions']['submit'] = [
        '#type' => 'submit',
        '#value' => $this->t('Filter'),
      ];
      if (!empty($_SESSION['nal_filter_key'])) {
        $form['filters']['actions']['reset'] = [
          '#type' => 'submit',
          '#value' => $this->t('Reset'),
          '#limit_validation_errors' => [],
          '#submit' => ['::resetForm'],
        ];
      }
      return $form;
    }

    /**
     * {@inheritdoc}
     */
    public function validateForm(array &$form, FormStateInterface $form_state) {
      if ($form_state->isValueEmpty('key')) {
        $form_state->setErrorByName('key', $this->t('You must select atleast one option.'));
      }
    }

    /**
     * {@inheritdoc}
     */
    public function submitForm(array &$form, FormStateInterface $form_state) {
      if ($form_state->hasValue('key')) {
        $_SESSION['nal_filter_key'] = $form_state->getValue('key');
      }
    }

    /**
     * Resets the filter form.
     *
     * @param array $form
     *   An associative array containing the structure of the form.
     * @param \Drupal\Core\Form\FormStateInterface $form_state
     *   The current state of the form.
     */
    public function resetForm(array &$form, FormStateInterface $form_state) {
      $_SESSION['nal_filter_key'] = [];
    }

  }
